@@ -5,7 +5,8 @@ import random
 from mono.api.misc import Misc
 from mono.api.errors import MonoAuthException
 
-TEST_MONO_SEC_KEY = 'test_sk_xxxxxxxxxxxxx'
+
+TEST_MONO_SEC_KEY = os.environ.get('TEST_MONO_SEC_KEY')
 
 
 @pytest.fixture(scope='module')
@@ -38,3 +39,12 @@ def test_institutions(mono_instance):
     '''
     status, response = mono_instance.institutions()
     assert status and len(response) >= 1 #at least one or more info present
+
+
+def test_business_lookup(mono_instance):
+    '''
+    test the business lookup endpoint to fetch information about a company
+    '''
+    # I noticed if name isn't in the db -> Response 504 [time out]
+    status, response = mono_instance.business_lookup(name='polaris bank')
+    assert status and response[0]['status'] #status -> ACTIVE or INACTIVE 
\ No newline at end of file
